import { gameRequestApi } from "@/api/common.js";
const {
    getPlayCount,
    validGame,
    gamePlay
} = gameRequestApi;

export function Manager(component) {
    let _component;
    if (component) {
        _component = component;
    }

    this.init = (component) => {
        _component = component;
    }

    const showAlert = (options) => {
        _component.alertOptions = options;
    }

    const hiddenAlert = () => {
        _component.alertOptions = {};
    }


    const checkAttest = () => {
        return new Promise((resolve, reject) => {
            let query = _component.$route.query;
            if (query.isAttest) {
                resolve();
                return;
            } else {
                reject();
                showAlert({
                    show: true,
                    content: "成为会员才可参与游戏哦~<br/>快认证成为会员赢好礼吧！",
                    buttonList: [
                        {
                            text: "立即认证",
                            click: () => {
                                hiddenAlert();
                                // TODO
                            },
                        },
                    ],
                    cancel: () => {
                        hiddenAlert();
                    },
                });
            }
        });
    }

    const checkTime = () => {
        return new Promise((resolve, reject) => {
            let game = _component.game;
            let content = "无法参与游戏";
            switch (+game.status) {
                case 0:
                    content = "游戏还没开始，请耐心等待,\n去其他地方先逛逛吧~";
                    break;
                case 1:
                    resolve();
                    return;
                case 2:
                    content = "来晚一步，游戏已结束，\n去其他地方看看吧~";
                    break;
                case 3:
                    content = "来晚一步，游戏已下架，\n去其它地方看看吧~";
                    break;
                default:
                    break;
            }

            reject();
            showAlert({
                show: true,
                content: content,
                buttonList: [
                    {
                        text: "前往会员中心",
                        click: () => {
                            hiddenAlert();
                            // window.wx.miniProgram
                            // TODO
                        },
                    },
                ],
                cancel: () => {
                    hiddenAlert();
                },
            });

        });
    }

    const checkCount = () => {
        return new Promise((resolve, reject) => {

            let query = _component.$route.query;
            getPlayCount(query).then((res) => {
                let rule = _component.rule;
                if (rule.playTimes > res) {
                    resolve();
                } else {
                    reject();
                    showAlert({
                        show: true,
                        content: rule.giveawayType == '21' ? "今日免费次数已用完，明早继续" : '免费游戏次数已用完，去其他地方看看吧~',
                        buttonList: [
                            {
                                text: "前往会员中心",
                                click: () => {
                                    hiddenAlert();
                                    // TODO
                                },
                            },
                        ],
                        cancel: () => {
                            hiddenAlert();
                        },
                    });
                }
            }).catch(() => {
                resolve();
            })

        });
    }

    const checkLimit = () => {
        return new Promise((resolve) => {
            validGame(_component.$route.query).then(resolve).catch(() => {
                showAlert({
                    show: true,
                    title: "很遗憾",
                    content: "您暂无权限参加本次游戏，详情请查看游戏规则",
                    buttonList: [
                        {
                            text: "查看规则",
                            click: () => {
                                hiddenAlert();
                                this.toGameRule();
                            },
                        },
                    ],
                    cancel: () => {
                        hiddenAlert();
                    },
                })
            })
        })
    }

    const play = () => {
        return new Promise((resolve, reject) => {
            gamePlay(_component.$route.query).then(resolve).catch((res) => {
                reject(res);
                let content = "";
                let title = "";
                let buttonList = [
                    {
                        text: "前往会员中心",
                        click: () => {
                            hiddenAlert();
                            // TODO
                        },
                    },
                ];
                switch (+res.code) {
                    case 2001:
                        // 游戏已结束
                        content = "来晚一步，游戏已结束，\n去其他地方看看吧~";
                        break;
                    case 2002:
                        // 游戏未开始
                        content = "游戏还没开始，请耐心等待，\n去其他地方看看吧~";
                        break;
                    case 2003:
                        // 游戏无权限
                        title = "很遗憾";
                        content = "您暂无权限参加本次游戏，\n详情请查看游戏规则";
                        buttonList = [{
                            text: "查看规则",
                            click: () => {
                                hiddenAlert();
                                _component.toGameRule();
                            },
                        }];
                        break;
                    case 2004:
                        // 抽奖次数已达上限
                        content = "游戏次数已达上限，\n去其他地方看看吧~";
                        break;
                    case 2005:
                        // 用户游戏抽奖次数小于0
                        content = "游戏次数已达上限，\n去其他地方看看吧~";
                        break;
                    case 2006:
                        // 用户积分不足
                        content = "当前积分不足，\n去先去获取些积分吧~";
                        buttonList = [{
                            text: "立即获取积分",
                            click: () => {
                                hiddenAlert();
                            },
                        }];
                        break;
                    case 2007:
                        // 用户游戏抽奖今日免费次数小于0
                        content = "今日免费次数已用完，\n明早继续";
                        break;
                    case 2008:
                        // 用户游戏抽奖总免费次数小于0
                        content = "免费游戏次数已达上限，\n去其他地方看看吧~";
                        break;
                    default:
                        content = res.message || "系统异常";
                        buttonList = [];
                        break;
                }
                console.log(title,content);
                if(title || content){
                    showAlert({
                        show: true,
                        title: title,
                        content: content,
                        buttonList: buttonList,
                        cancel: () => {
                            hiddenAlert();
                        },
                    })
                }
            })
        })
    }

    this.play = () => {
        return checkTime()
            .then(checkAttest)
            .then(checkCount)
            .then(checkLimit)
            .then(() => {
                return play();
            })
    }


    return this;
}
